@@ -40,7 +40,7 @@ def quant(args):
         currently the sum of intensities is returned if multiple peaks are within the tolerance of reporter
 
     Usage:
-        pytmt tests/data/mzml tests/data/percolator -o ~/Desktop/pytmt
+        pytmt tests/data/mzml tests/data/percolator/percolator.target.psms.txt -o out
 
     Example values for arguments:
         mzml_loc = 'tests/data/mzml'
@@ -97,17 +97,50 @@ def quant(args):
     # Define the Percolator protein-unique PSM filter
     unique_only = args.unique
 
-    assert os.path.isdir(mzml_loc), '[error] mzml directory not valid'
-    assert os.path.isdir(id_loc), '[error] percolator directory not valid'
+    assert os.path.isdir(mzml_loc), '[error] mzml directory path not valid'
+    assert os.path.isfile(id_loc), '[error] percolator file path not valid'
 
     # List all files in the percolator directory ending with target.psms.txt.
-    id_files = [f for f in os.listdir(id_loc) if f.endswith('target.psms.txt')]
-
-    assert len(id_files) == 1, 'Check percolator output directory has 1 *.target.psms.txt'
+        # id_files = [f for f in os.listdir(id_loc) if f.endswith('target.psms.txt')]
+        # assert len(id_files) == 1, 'Check percolator output directory has 1 *.target.psms.txt'
 
     # Read the Percolator psms file.
-    id_df = pd.read_csv(filepath_or_buffer=os.path.join(id_loc, id_files[0]),
-                        sep='\t')
+    try:
+        id_df = pd.read_csv(filepath_or_buffer=id_loc,  # os.path.join(id_loc, id_files[0]),
+                            sep='\t')
+    except pd.errors.ParserError:
+        main_log.info("Pandas ParserError: trying readlines for possible standalone Percolator file")
+
+        with open(id_loc, 'r') as f:
+            f_ln = f.readlines()
+
+        # The percolator output has different number of columns per row because the proteins are separated by tabs
+        # Read the first half of the table without the protein IDs
+        id_df = pd.DataFrame([ln.split('\t')[0:5] for ln in f_ln[1:]])
+        id_df.columns = ['PSMId', 'score', 'percolator q-value', 'posterior_error_prob', 'peptide']
+        id_df['percolator q-value'] = id_df['percolator q-value'].astype(float)
+        id_df['posterior_error_prob'] = id_df['posterior_error_prob'].astype(float)
+
+        # Create a sequence column for compatibility
+        id_df['sequence'] = [pep[2:-2] for pep in id_df['peptide']]
+
+        # Then read in the protein names and join them by comma instead of tab
+        id_df['protein id'] = [','.join(ln.rstrip().split('\t')[5:]) for ln in f_ln[1:]]
+
+        # Split the PSMId column to create file_idx, scan, and charge.
+        id_df['charge'] = [psm.split('_')[-2] for psm in id_df['PSMId']]
+        id_df['charge'] = id_df['charge'].astype(int)
+        id_df['scan'] = [psm.split('_')[-3] for psm in id_df['PSMId']]
+        id_df['scan'] = id_df['scan'].astype(int)
+        # The file name is the underscore('_') split until the last 3 parts, then rejoined by underscore
+        # in case there are underscores in the filename. We then remove everything
+        # We then remove all directories to get base name
+        id_df['file_name'] = [os.path.basename('_'.join(psm.split('_')[:-3])) for psm in id_df['PSMId']]
+
+        # Get the sorted file names, hopefully this is the same index as the Crux Percolator output
+        # TODO: Read the Percolator log file to get actual index and use file names to open the mzml instead
+        sorted_index = sorted(set(id_df['file_name']))
+        id_df['file_idx'] = id_df['file_name'].apply(sorted_index.index)
 
     # Get all the file indices in the Percolator results file.
     file_indices = list(set(id_df['file_idx']))
@@ -228,12 +261,12 @@ def main():
 
     import argparse
 
-    parser = argparse.ArgumentParser(description='pytmt returns ms2 tmt quantification'
-                                                 'values from Crux Percolator output')
+    parser = argparse.ArgumentParser(description='pytmt returns ms2 tmt quantification values'
+                                                 'from Percolator (Crux or Standalone) output')
 
     parser.add_argument('mzml', help='path to folder containing mzml files')
 
-    parser.add_argument('id', help='path to folder containing percolator tab-delimited files')
+    parser.add_argument('id', help='path to percolator target psms output file')
 
     parser.add_argument('-u', '--unique', action='store_true', help='quantify unique peptides only')
 
